==> client-java-api-4.0.0-sources.jar: io/kubernetes/client/models/V1FlexVolumeSourceFluent.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Boolean;
import java.util.Map;

public interface V1FlexVolumeSourceFluent<A extends V1FlexVolumeSourceFluent<A>> extends Fluent<A>{


    public String getDriver();
    public A withDriver(String driver);
    public Boolean hasDriver();
    public String getFsType();
    public A withFsType(String fsType);
    public Boolean hasFsType();
    public A addToOptions(String key,String value);
    public A addToOptions(Map<String,String> map);
    public A removeFromOptions(String key);
    public A removeFromOptions(Map<String,String> map);
    public Map<String,String> getOptions();
    public A withOptions(Map<String,String> options);
    public Boolean hasOptions();
    public Boolean isReadOnly();
    public A withReadOnly(Boolean readOnly);
    public Boolean hasReadOnly();
    public A withNewReadOnly(boolean arg1);
    public A withNewReadOnly(String arg1);
    
/**
 * This method has been deprecated, please use method buildSecretRef instead.
 * @return The buildable object.
 */
@Deprecated public V1LocalObjectReference getSecretRef();
    public V1LocalObjectReference buildSecretRef();
    public A withSecretRef(V1LocalObjectReference secretRef);
    public Boolean hasSecretRef();
    public V1FlexVolumeSourceFluent.SecretRefNested<A> withNewSecretRef();
    public V1FlexVolumeSourceFluent.SecretRefNested<A> withNewSecretRefLike(V1LocalObjectReference item);
    public V1FlexVolumeSourceFluent.SecretRefNested<A> editSecretRef();
    public V1FlexVolumeSourceFluent.SecretRefNested<A> editOrNewSecretRef();
    public V1FlexVolumeSourceFluent.SecretRefNested<A> editOrNewSecretRefLike(V1LocalObjectReference item);

    public interface SecretRefNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1LocalObjectReferenceFluent<V1FlexVolumeSourceFluent.SecretRefNested<N>>{

        
    public N and();    public N endSecretRef();
}


}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/V1FlexVolumeSourceFluent.java <==
package io.kubernetes.client.models;

import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Boolean;
import java.util.Map;

public interface V1FlexVolumeSourceFluent<A extends V1FlexVolumeSourceFluent<A>> extends Fluent<A>{


    public String getDriver();
    public A withDriver(String driver);
    public Boolean hasDriver();
    public A withNewDriver(String arg1);
    public A withNewDriver(StringBuilder arg1);
    public A withNewDriver(StringBuffer arg1);
    public String getFsType();
    public A withFsType(String fsType);
    public Boolean hasFsType();
    public A withNewFsType(String arg1);
    public A withNewFsType(StringBuilder arg1);
    public A withNewFsType(StringBuffer arg1);
    public A addToOptions(String key,String value);
    public A addToOptions(Map<String,String> map);
    public A removeFromOptions(String key);
    public A removeFromOptions(Map<String,String> map);
    public Map<String,String> getOptions();
    public A withOptions(Map<String,String> options);
    public Boolean hasOptions();
    public Boolean isReadOnly();
    public A withReadOnly(Boolean readOnly);
    public Boolean hasReadOnly();
    public A withNewReadOnly(String arg1);
    public A withNewReadOnly(boolean arg1);
    
/**
 * This method has been deprecated, please use method buildSecretRef instead.
 * @return The buildable object.
 */
@Deprecated public V1LocalObjectReference getSecretRef();
    public V1LocalObjectReference buildSecretRef();
    public A withSecretRef(V1LocalObjectReference secretRef);
    public Boolean hasSecretRef();
    public V1FlexVolumeSourceFluent.SecretRefNested<A> withNewSecretRef();
    public V1FlexVolumeSourceFluent.SecretRefNested<A> withNewSecretRefLike(V1LocalObjectReference item);
    public V1FlexVolumeSourceFluent.SecretRefNested<A> editSecretRef();
    public V1FlexVolumeSourceFluent.SecretRefNested<A> editOrNewSecretRef();
    public V1FlexVolumeSourceFluent.SecretRefNested<A> editOrNewSecretRefLike(V1LocalObjectReference item);

    public interface SecretRefNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1LocalObjectReferenceFluent<V1FlexVolumeSourceFluent.SecretRefNested<N>>{

        
    public N and();    public N endSecretRef();
}


}
